WindowsProxyManager (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

## org.openqa.selenium.server.browserlaunchers
Class WindowsProxyManager

    java.lang.Object
      org.openqa.selenium.server.browserlaunchers.WindowsProxyManager

    public class WindowsProxyManager

extends java.lang.Object

Field Summary
`protected static java.lang.String` | `COOKIE_SUFFIX`
`protected static java.io.File` | `HIDDEN_COOKIE_DIR`
`protected static java.lang.String` | `REG_KEY_BACKUP_READY`
`protected static java.lang.String` | `REG_KEY_BASE`

Constructor Summary
`WindowsProxyManager(boolean customPACappropriate, java.lang.String sessionId, int port, int portDriversShouldContact)`

Method Summary
`void` | `backupRegistrySettings()`
`protected void` | `changeRegistrySettings(boolean ensureCleanSession, boolean avoidProxy)`
`protected static void` | `deleteFlatDirContents(java.io.File dir, java.lang.String suffix)` Deletes all files contained by the given directory.
`boolean` | `getChangeMaxConnections()`
`java.io.File` | `getCustomProxyPACDir()`
`protected void` | `handleEvilPopupMgrBackup()`
`protected static boolean` | `hideCookies(java.io.File cookieDir, java.lang.String cookieSuffix, java.io.File hiddenCookieDir)` Hides all previously existing user cookies, found in the WinXP directory structure, by moving them to a different directory.
`protected void` | `init()`
`protected static boolean` | `restoreCookies(java.io.File cookieDir, java.lang.String cookieSuffix, java.io.File hiddenCookieDir)` Restores previously hidden user cookies, if any.
`void` | `restoreRegistrySettings(boolean ensureCleanSession)`
`static void` | `setBaseRegKey(java.lang.String base)`
`void` | `setChangeMaxConnections(boolean changeMaxConnections)`

Methods inherited from class java.lang.Object
`clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

Field Detail

### REG_KEY_BACKUP_READY

    protected static final java.lang.String REG_KEY_BACKUP_READY

See Also:
  Constant Field Values

### COOKIE_SUFFIX

    protected static final java.lang.String COOKIE_SUFFIX

See Also:
  Constant Field Values

### HIDDEN_COOKIE_DIR

    protected static final java.io.File HIDDEN_COOKIE_DIR

### REG_KEY_BASE

    protected static java.lang.String REG_KEY_BASE

Constructor Detail

### WindowsProxyManager

    public WindowsProxyManager(boolean customPACappropriate,
                               java.lang.String sessionId,
                               int port,
                               int portDriversShouldContact)

Method Detail

### setChangeMaxConnections

    public void setChangeMaxConnections(boolean changeMaxConnections)

### getChangeMaxConnections

    public boolean getChangeMaxConnections()

### getCustomProxyPACDir

    public java.io.File getCustomProxyPACDir()

### init

    protected void init()

### handleEvilPopupMgrBackup

    protected void handleEvilPopupMgrBackup()

### setBaseRegKey

    public static void setBaseRegKey(java.lang.String base)

### changeRegistrySettings

    protected void changeRegistrySettings(boolean ensureCleanSession,
                                          boolean avoidProxy)
                                   throws java.io.IOException

  Throws:
    `java.io.IOException`

### backupRegistrySettings

    public void backupRegistrySettings()

### restoreRegistrySettings

    public void restoreRegistrySettings(boolean ensureCleanSession)

### hideCookies

    protected static boolean hideCookies(java.io.File cookieDir,
                                         java.lang.String cookieSuffix,
                                         java.io.File hiddenCookieDir)

  Hides all previously existing user cookies, found in the WinXP directory structure, by moving them to a different directory.

### restoreCookies

    protected static boolean restoreCookies(java.io.File cookieDir,
                                            java.lang.String cookieSuffix,
                                            java.io.File hiddenCookieDir)

  Restores previously hidden user cookies, if any.

### deleteFlatDirContents

    protected static void deleteFlatDirContents(java.io.File dir,
                                                java.lang.String suffix)

  Deletes all files contained by the given directory.

  Parameters:
    `dir` - the directory to delete the contents of
    `suffix` - if not null, only files with this suffix will be deleted.

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

Copyright © 2009. All Rights Reserved.